%define         major                    15
%define         netmajor                 0

%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d

%define         netname                  netloc
%define         libnetname               %mklibname %{netname} %{netmajor}
%define         netdevelname             %mklibname %{netname} -d

Name:           hwloc
Summary:        Hardware locality utilities and libraries
Version:        2.11.2
Release:        %mkrel 1
License:        BSD
Group:          System/Libraries
URL:            https://www.open-mpi.org/projects/hwloc/
Source0:        https://www.open-mpi.org/software/hwloc/v%(cut -d. -f1,2 <<< %{version})/downloads/%{name}-%{version}.tar.bz2

%ifnarch %arm
BuildRequires:  numa-devel
%endif
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(pciaccess)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(OpenCL)

%description
The Portable Hardware Locality software package provides a portable
abstraction of the hierarchical topology of modern architectures,
including NUMA memory nodes, sockets, shared caches, cores and
simultaneous multi-threading. It also gathers various system attributes
such as cache and memory information as well as the locality of I/O
devices such as network interfaces, InfiniBand HCAs or GPUs. It
primarily aims at helping applications with gathering information
about modern computing hardware so as to exploit it accordingly and
efficiently. Try out the command "lstopo" and enjoy the show.

%package -n %{libname}
Summary:        Shared libraries for hwloc
Group:          System/Libraries
Provides:       lib%{name} = %{version}-%{release}
Obsoletes:      %{_lib}netloc0 < 2.10.0

%description -n %{libname}
%{summary}.

%package -n %{develname}
Summary:        Development files for hwloc
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       lib%{name}-devel  = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{_lib}netloc-devel < 2.10.0

%description -n %{develname}
%{summary}.

%prep
%autosetup -p1

%build

%configure
%make_build

%install
%make_install

%files
%doc README COPYING
%doc %{_docdir}/%{name}/*.pdf
%doc %{_docdir}/%{name}/*.html
# This binary is built only for Intel architectures
%ifarch %ix86 x86_64
%{_sbindir}/hwloc-dump-hwdata
%endif
%{_bindir}/hwloc*
%{_bindir}/lstopo*
%{_datadir}/bash-completion/completions/hwloc
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%{_mandir}/man1/*.1*.*
%{_mandir}/man7/*.7.*

%files -n %{libname}
%{_libdir}/libhwloc.so.%{major}{,.*}

%files -n %{develname}
%doc AUTHORS VERSION NEWS
%{_includedir}/hwloc.h
%{_includedir}/%{name}/
%{_libdir}/libhwloc.so
%{_libdir}/pkgconfig/hwloc.pc
%{_mandir}/man3/HWLOC*.3.*
%{_mandir}/man3/hwloc*.3.*


%changelog
* Wed Dec 04 2024 eatdirt <eatdirt> 2.11.2-1.mga10
+ Revision: 2121599
- Update to version 2.11.2

* Mon Sep 02 2024 eatdirt <eatdirt> 2.11.1-1.mga10
+ Revision: 2092692
- Update to version 2.11.1

* Wed Feb 21 2024 eatdirt <eatdirt> 2.10.0-2.mga10
+ Revision: 2043000
- Add obsoletes to abandonned subpackage libnetloc

* Sat Feb 17 2024 eatdirt <eatdirt> 2.10.0-1.mga10
+ Revision: 2042197
- Upgrade to version 2.10.0
+ wally <wally>
- new version 2.9.3

* Thu May 04 2023 daviddavid <daviddavid> 2.9.1-2.mga9
+ Revision: 1955807
- fix owner of include dir

* Fri Apr 07 2023 eatdirt <eatdirt> 2.9.1-1.mga9
+ Revision: 1951651
- Update to version 2.9.1

* Fri Jan 20 2023 eatdirt <eatdirt> 2.9.0-1.mga9
+ Revision: 1934491
- Update to version 2.9.0

* Thu Aug 25 2022 eatdirt <eatdirt> 2.8.0-1.mga9
+ Revision: 1880299
- Update to version 2.8.0

* Thu May 05 2022 eatdirt <eatdirt> 2.7.1-1.mga9
+ Revision: 1856365
- Update to version 2.7.1

* Wed Mar 30 2022 umeabot <umeabot> 2.7.0-2.mga9
+ Revision: 1835040
- Mageia 9 Mass Rebuild

* Tue Dec 14 2021 eatdirt <eatdirt> 2.7.0-1.mga9
+ Revision: 1762078
- Update to version 2.7.0

* Fri Aug 27 2021 eatdirt <eatdirt> 2.5.0-1.mga9
+ Revision: 1742857
- Upgrade to version 2.5.0

* Sun Dec 06 2020 eatdirt <eatdirt> 2.3.0-1.mga8
+ Revision: 1653710
- Upgrade to stable version

* Sat Jul 11 2020 eatdirt <eatdirt> 2.2.0-1.mga8
+ Revision: 1605135
- Upgrade to version 2.2.0

* Wed Mar 18 2020 eatdirt <eatdirt> 2.1.0-2.mga8
+ Revision: 1557832
+ rebuild (emptylog)

* Wed Mar 18 2020 eatdirt <eatdirt> 2.1.0-1.mga8
+ Revision: 1557827
- Upgrade to version 2.1.0

* Sun Feb 16 2020 umeabot <umeabot> 2.0.4-2.mga8
+ Revision: 1530397
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Aug 28 2019 daviddavid <daviddavid> 2.0.4-1.mga8
+ Revision: 1434792
- new version: 2.0.4

* Sat Dec 29 2018 luigiwalser <luigiwalser> 2.0.3-1.mga7
+ Revision: 1346435
- 2.0.3

* Tue Oct 09 2018 eatdirt <eatdirt> 2.0.2-1.mga7
+ Revision: 1319093
- Upgrade to version 2.0.2

* Sun Sep 23 2018 umeabot <umeabot> 2.0.1-2.mga7
+ Revision: 1298231
- Mageia 7 Mass Rebuild

* Wed May 16 2018 eatdirt <eatdirt> 2.0.1-1.mga7
+ Revision: 1229870
- Upgrade to version 2.0.1

* Tue May 02 2017 eatdirt <eatdirt> 1.11.7-1.mga6
+ Revision: 1098503
- Upgrade to version 1.11.7

* Fri Mar 03 2017 eatdirt <eatdirt> 1.11.6-1.mga6
+ Revision: 1088571
- Upgrade to version 1.11.6

* Thu Dec 01 2016 eatdirt <eatdirt> 1.11.5-1.mga6
+ Revision: 1071464
- Upgrade to bug fix release 1.11.5

* Sat Sep 10 2016 luigiwalser <luigiwalser> 1.11.4-1.mga6
+ Revision: 1051251
- 1.11.4

* Fri Jun 24 2016 eatdirt <eatdirt> 1.11.3-1.mga6
+ Revision: 1037443
- Upgrade to buxfix release 1.11.3

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.11.2-1.mga6
+ Revision: 918965
- 1.11.2

* Sat Oct 10 2015 eatdirt <eatdirt> 1.11.0-2.mga6
+ Revision: 888685
- Fix files list

* Sun Aug 16 2015 eatdirt <eatdirt> 1.11.0-1.mga6
+ Revision: 865147
- Upgrade to version 1.11.0

* Wed Oct 15 2014 umeabot <umeabot> 1.9.1-3.mga5
+ Revision: 748950
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.9.1-2.mga5
+ Revision: 680333
- Mageia 5 Mass Rebuild

* Wed Sep 03 2014 eatdirt <eatdirt> 1.9.1-1.mga5
+ Revision: 671552
- Upgrade to version 1.9.1

* Thu Apr 10 2014 eatdirt <eatdirt> 1.9-1.mga5
+ Revision: 613143
- Upgrade to version 1.9

* Fri Feb 28 2014 eatdirt <eatdirt> 1.8.1-1.mga5
+ Revision: 597748
- Upgrade to version 1.8.1

* Sun Oct 20 2013 umeabot <umeabot> 1.7.2-2.mga4
+ Revision: 536772
- Mageia 4 Mass Rebuild

* Tue Sep 24 2013 eatdirt <eatdirt> 1.7.2-1.mga4
+ Revision: 485519
- Upgrade to version 1.7.2

* Sat Jun 08 2013 fwang <fwang> 1.7.1-2.mga4
+ Revision: 440483
- cleanup br

* Mon May 27 2013 eatdirt <eatdirt> 1.7.1-1.mga4
+ Revision: 428957
- Upgrade to version 1.7.1

* Sat Jan 12 2013 umeabot <umeabot> 1.6-2.mga3
+ Revision: 353789
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 eatdirt <eatdirt> 1.6-1.mga3
+ Revision: 343154
- Upgrade to version 1.6

* Thu Dec 27 2012 rtp <rtp> 1.5.1-2.mga3
+ Revision: 335686
- disable numa build-dep on arm (no numa on arm atm)

* Sat Nov 03 2012 eatdirt <eatdirt> 1.5.1-1.mga3
+ Revision: 312724
- Upgrade to version 1.5.1

* Sat Sep 01 2012 eatdirt <eatdirt> 1.5-1.mga3
+ Revision: 287067
- imported package hwloc

